@@ -2,7 +2,7 @@
 import sys
 
 
-__version__ = '5.0.1'
+__version__ = '5.1.0'
 
 API_PATH = {
     'about_edited':           'r/{subreddit}/about/edited/',
@@ -18,6 +18,7 @@ API_PATH = {
     'approve':                'api/approve/',
     'block':                  'api/block',
     'blocked':                'prefs/blocked/',
+    'collapse':               'api/collapse_message/',
     'comment':                'api/comment/',
     'comment_replies':        'message/comments/',
     'compose':                'api/compose/',
@@ -147,6 +148,7 @@ API_PATH = {
     'subreddits_search':      'subreddits/search/',
     'subscribe':              'api/subscribe/',
     'suggested_sort':         'api/set_suggested_sort/',
+    'uncollapse':             'api/uncollapse_message/',
     'unfriend':               'r/{subreddit}/api/unfriend/',
     'unhide':                 'api/unhide/',
     'unignore_reports':       'api/unignore_reports/',
